@@ -3,32 +3,36 @@
 A PEP-0249 compatible driver for interfacing with Wherobots DB.
 """
 
+import ssl
 from importlib import metadata
 from importlib.metadata import PackageNotFoundError
 import logging
 from packaging.version import Version
 import platform
-import queue
 import requests
 import tenacity
-from typing import Union
+from typing import Final, Union, Dict
 import urllib.parse
 import websockets.sync.client
+import certifi
 
 from .connection import Connection
 from .constants import (
     DEFAULT_ENDPOINT,
     DEFAULT_REGION,
-    DEFAULT_REUSE_SESSION,
     DEFAULT_RUNTIME,
     DEFAULT_READ_TIMEOUT_SECONDS,
+    DEFAULT_SESSION_TYPE,
     DEFAULT_SESSION_WAIT_TIMEOUT_SECONDS,
+    DEFAULT_VERSION,
     MAX_MESSAGE_SIZE,
+    PARAM_STYLE,
     PROTOCOL_VERSION,
     AppStatus,
     DataCompression,
     GeometryRepresentation,
     ResultsFormat,
+    SessionType,
 )
 from .errors import (
     InterfaceError,
@@ -39,7 +43,7 @@ from .runtime import Runtime
 
 apilevel = "2.0"
 threadsafety = 1
-paramstyle = "pyformat"
+paramstyle: Final[str] = PARAM_STYLE
 
 
 def gen_user_agent_header():
@@ -56,13 +60,14 @@ def gen_user_agent_header():
 
 def connect(
     host: str = DEFAULT_ENDPOINT,
-    token: str = None,
-    api_key: str = None,
-    runtime: Runtime = None,
-    region: Region = None,
+    token: Union[str, None] = None,
+    api_key: Union[str, None] = None,
+    runtime: Union[Runtime, None] = None,
+    region: Union[Region, None] = None,
+    version: Union[str, None] = None,
     wait_timeout: float = DEFAULT_SESSION_WAIT_TIMEOUT_SECONDS,
     read_timeout: float = DEFAULT_READ_TIMEOUT_SECONDS,
-    reuse_session: bool = DEFAULT_REUSE_SESSION,
+    session_type: Union[SessionType, None] = None,
     shutdown_after_inactive_seconds: Union[int, None] = None,
     results_format: Union[ResultsFormat, None] = None,
     data_compression: Union[DataCompression, None] = None,
@@ -82,11 +87,13 @@ def connect(
     host = host or DEFAULT_ENDPOINT
     runtime = runtime or DEFAULT_RUNTIME
     region = region or DEFAULT_REGION
+    version = version or DEFAULT_VERSION
+    session_type = session_type or DEFAULT_SESSION_TYPE
 
     logging.info(
-        "%s %s runtime in %s from %s ...",
-        "Recycling" if reuse_session else "Requesting",
+        "Requesting %s runtime running %s in %s from %s ...",
         runtime.value,
+        version,
         region.value,
         host,
     )
@@ -98,16 +105,26 @@ def connect(
     try:
         resp = requests.post(
             url=f"{host}/sql/session",
-            params={"region": region.value, "reuse_session": reuse_session},
+            params={"region": region.value},
             json={
                 "runtimeId": runtime.value,
                 "shutdownAfterInactiveSeconds": shutdown_after_inactive_seconds,
+                "version": version,
+                "sessionType": session_type.value,
             },
             headers=headers,
         )
         resp.raise_for_status()
     except requests.HTTPError as e:
-        raise InterfaceError("Failed to create SQL session!", e)
+        details = str(e)
+        try:
+            info = e.response.json()
+            errors = info.get("errors", [])
+            if errors and isinstance(errors, list):
+                details = f"{errors[0]['message']}: {errors[0]['details']}"
+        except requests.JSONDecodeError:
+            pass
+        raise InterfaceError(f"Failed to create SQL session: {details}") from e
 
     # At this point we've been redirected to /sql/session/{session_id}, which we'll need to keep polling until the
     # session is in READY state.
@@ -163,21 +180,23 @@ def http_to_ws(uri: str) -> str:
 def connect_direct(
     uri: str,
     protocol: Version = PROTOCOL_VERSION,
-    headers: dict[str, str] = None,
+    headers: Union[Dict[str, str], None] = None,
     read_timeout: float = DEFAULT_READ_TIMEOUT_SECONDS,
     results_format: Union[ResultsFormat, None] = None,
     data_compression: Union[DataCompression, None] = None,
     geometry_representation: Union[GeometryRepresentation, None] = None,
 ) -> Connection:
-    q = queue.SimpleQueue()
     uri_with_protocol = f"{uri}/{protocol}"
 
     try:
         logging.info("Connecting to SQL session at %s ...", uri_with_protocol)
+        ssl_context = ssl.create_default_context()
+        ssl_context.load_verify_locations(certifi.where())
         ws = websockets.sync.client.connect(
             uri=uri_with_protocol,
             additional_headers=headers,
             max_size=MAX_MESSAGE_SIZE,
+            ssl=ssl_context,
         )
     except Exception as e:
         raise InterfaceError("Failed to connect to SQL session!") from e
